@@ -15,15 +15,31 @@
 
 from persepolis.scripts.useful_tools import humanReadableSize
 from requests.cookies import cookiejar_from_dict
+from persepolis.constants import VERSION
 from http.cookies import SimpleCookie
 import requests
+from pathlib import Path
+from urllib.parse import urlparse, unquote
 
 
 # for more information about "requests" library , please see
 # http://docs.python-requests.org/en/master/
 
 
+def getFileNameFromLink(link):
+    parsed_linkd = urlparse(link)
+    file_name = Path(parsed_linkd.path).name
+
+    # URL might contain percent-encoded characters
+    # for example farsi characters in link
+    if file_name.find('%'):
+        file_name = unquote(file_name)
+
+    return file_name
+
 # spider function finds name of file and file size from header
+
+
 def spider(add_link_dictionary):
 
     # get user's download request from add_link_dictionary
@@ -32,6 +48,7 @@ def spider(add_link_dictionary):
     port = add_link_dictionary['port']
     proxy_user = add_link_dictionary['proxy_user']
     proxy_passwd = add_link_dictionary['proxy_passwd']
+    proxy_type = add_link_dictionary['proxy_type']
     download_user = add_link_dictionary['download_user']
     download_passwd = add_link_dictionary['download_passwd']
     header = add_link_dictionary['header']
@@ -42,12 +59,22 @@ def spider(add_link_dictionary):
 
     # define a requests session
     requests_session = requests.Session()
+    # check if user set proxy
     if ip:
-        ip_port = 'http://' + str(ip) + ":" + str(port)
+        ip_port = '://' + str(ip) + ":" + str(port)
         if proxy_user:
-            ip_port = 'http://' + proxy_user + ':' + proxy_passwd + '@' + ip_port
+            ip_port = ('://' + proxy_user + ':'
+                       + proxy_passwd + '@' + ip_port)
+        if proxy_type == 'socks5':
+            ip_port = 'socks5' + ip_port
+        else:
+            ip_port = 'http' + ip_port
+
+        proxies = {'http': ip_port,
+                   'https': ip_port}
+
         # set proxy to the session
-        requests_session.proxies = {'http': ip_port}
+        requests_session.proxies.update(proxies)
 
     if download_user:
         # set download user pass to the session
@@ -68,27 +95,37 @@ def spider(add_link_dictionary):
     # set user_agent
     if user_agent:
         requests_session.headers.update({'user-agent': user_agent})  # setting user_agent to the session
+    else:
+        user_agent = 'PersepolisDM/' + str(VERSION.version_str)
+
+        # setting user_agent to the session
+        requests_session.headers.update(
+            {'user-agent': user_agent})
 
     # find headers
     try:
-        response = requests_session.head(link, timeout=2.50)
+        response = requests_session.head(link, timeout=2.50, allow_redirects=True)
         header = response.headers
     except:
         header = {}
 
     filename = None
     file_size = None
-    if 'Content-Disposition' in header.keys():  # checking if filename is available
+    # check if filename is available in header
+    if 'Content-Disposition' in header.keys():
         content_disposition = header['Content-Disposition']
+
         if content_disposition.find('filename') != -1:
+
+            # so file name is available in header
             filename_splited = content_disposition.split('filename=')
             filename_splited = filename_splited[-1]
 
             # getting file name in desired format
             filename = filename_splited.strip()
 
-    if not(filename):
-        filename = link.split('/')[-1]
+    if not (filename):
+        filename = getFileNameFromLink(link)
 
     # if user set file name before in add_link_dictionary['out'],
     # then set "out" for filename
@@ -97,118 +134,35 @@ def spider(add_link_dictionary):
 
     # check if file_size is available
     if 'Content-Length' in header.keys():
-        file_size = int(header['Content-Length'])
+        try:
+            file_size = int(header['Content-Length'])
 
-        # converting file_size to KiB or MiB or GiB
-        file_size = humanReadableSize(file_size)
+            # converting file_size to KiB or MiB or GiB
+            file_size, unit = humanReadableSize(file_size)
 
+            file_size_with_unit = str(file_size) + ' ' + unit
+        except Exception:
+            file_size_with_unit = 'None'
+    else:
+        file_size_with_unit = 'None'
+
+    requests_session.close()
     # return results
-    return filename, file_size
+    return filename, file_size_with_unit
 
 
 # this function finds and returns file name for links.
 def queueSpider(add_link_dictionary):
-    # get download information from add_link_dictionary
-    for i in ['link', 'header', 'out', 'user_agent', 'load_cookies', 'referer']:
-        if not (i in add_link_dictionary):
-            add_link_dictionary[i] = None
-
-    link = add_link_dictionary['link']
-    header = add_link_dictionary['header']
-    user_agent = add_link_dictionary['user_agent']
-    raw_cookies = add_link_dictionary['load_cookies']
-    referer = add_link_dictionary['referer']
-
-    requests_session = requests.Session()  # defining a requests Session
-
-    if raw_cookies:  # set cookies
-        cookie = SimpleCookie()
-        cookie.load(raw_cookies)
-
-        cookies = {key: morsel.value for key, morsel in cookie.items()}
-        requests_session.cookies = cookiejar_from_dict(cookies)
-
-    if referer:
-        # set referer to the session
-        requests_session.headers.update({'referer': referer})
-
-    if user_agent:
-        # set user_agent to the session
-        requests_session.headers.update({'user-agent': user_agent})
-
-    # find headers
-    try:
-        response = requests_session.head(link, timeout=2.50)
-        header = response.headers
-    except:
-        header = {}
-    filename = None
-    if 'Content-Disposition' in header.keys():  # checking if filename is available
-        content_disposition = header['Content-Disposition']
-        if content_disposition.find('filename') != -1:
-            filename_splited = content_disposition.split('filename=')
-            filename_splited = filename_splited[-1]
-            # getting file name in desired format
-            filename = filename_splited.strip()
-
-    if not(filename):
-        filename = link.split('/')[-1]
+    filename = addLinkSpider(add_link_dictionary)[0]
 
     return filename
 
 
 def addLinkSpider(add_link_dictionary):
     # get user's download information from add_link_dictionary
-    for i in ['link', 'header', 'out', 'user_agent', 'load_cookies', 'referer']:
+    for i in ['link', 'ip', 'port', 'proxy_user', 'proxy_passwd', 'download_user', 'download_passwd',
+              'header', 'out', 'user_agent', 'proxy_type', 'load_cookies', 'referer']:
         if not (i in add_link_dictionary):
             add_link_dictionary[i] = None
 
-    link = add_link_dictionary['link']
-    header = add_link_dictionary['header']
-    user_agent = add_link_dictionary['user_agent']
-    raw_cookies = add_link_dictionary['load_cookies']
-    referer = add_link_dictionary['referer']
-
-    requests_session = requests.Session()  # defining a requests Session
-
-    if raw_cookies:  # set cookies
-        cookie = SimpleCookie()
-        cookie.load(raw_cookies)
-
-        cookies = {key: morsel.value for key, morsel in cookie.items()}
-        requests_session.cookies = cookiejar_from_dict(cookies)
-
-    if referer:
-        # set referer to the session
-        requests_session.headers.update({'referer': referer})
-
-    if user_agent:
-        # set user_agent to the session
-        requests_session.headers.update({'user-agent': user_agent})
-
-    # find headers
-    try:
-        response = requests_session.head(link, timeout=2.50)
-        header = response.headers
-    except:
-        header = {}
-
-    # find file size
-    file_size = None
-    if 'Content-Length' in header.keys():  # checking if file_size is available
-        file_size = int(header['Content-Length'])
-
-        # converting file_size to KiB or MiB or GiB
-        file_size = str(humanReadableSize(file_size))
-
-    # find file name
-    file_name = None
-    if 'Content-Disposition' in header.keys():  # checking if filename is available
-        content_disposition = header['Content-Disposition']
-        if content_disposition.find('filename') != -1:
-            filename_splited = content_disposition.split('filename=')
-            filename_splited = filename_splited[-1]
-            # getting file name in desired format
-            file_name = filename_splited.strip()
-
-    return file_name, file_size  # If no Content-Length ? fixed it.
+    return spider(add_link_dictionary)
