@@ -18,6 +18,7 @@ import urllib.parse
 import subprocess
 import platform
 import textwrap
+import time
 import sys
 import os
 
@@ -42,6 +43,8 @@ os_type = platform.system()
 home_address = os.path.expanduser("~")
 
 # runApplication in a thread.
+
+
 class RunApplicationThread(QThread):
     RUNAPPCALLBACKSIGNAL = Signal(list)
 
@@ -57,6 +60,8 @@ class RunApplicationThread(QThread):
             self.RUNAPPCALLBACKSIGNAL.emit([pipe])
 
 # determine the config folder path based on the operating system
+
+
 def determineConfigFolder():
     if os_type in OS.UNIX_LIKE:
         config_folder = os.path.join(
@@ -83,29 +88,37 @@ def osAndDesktopEnvironment():
 
 
 # this function converts file_size to KiB or MiB or GiB
-def humanReadableSize(size, input_type='file_size'): 
+def humanReadableSize(size, input_type='file_size'):
     labels = ['KiB', 'MiB', 'GiB', 'TiB']
     i = -1
     if size < 1024:
-        return str(size) + ' B'
+        return str(size), 'B'
 
     while size >= 1024:
         i += 1
         size = size / 1024
-        
-    if input_type == 'speed':
-        j = 0
-    else:
-        j = 1
 
-    if i > j:
-        return str(round(size, 2)) + ' ' + labels[i]
+    if i > 1:
+        return round(size, 2), labels[i]
+    elif i == 1:
+        return round(size, 1), labels[i]
     else:
-        return str(round(size, None)) + ' ' + labels[i]
+        return round(size, None), labels[i]
+
+# this function converts second to hour and minute
+def convertTime(time):
+    minutes = int(time // 60)
+    if minutes == 0:
+        return str(int(time)) + 's'
+    elif minutes < 60:
+        return str(minutes) + 'm'
+    else:
+        hours = minutes // 60
+        minutes = minutes - (hours * 60)
+        return str(hours) + 'h ' + str(minutes) + 'm'
+
 
 # this function converts human readable size to byte
-
-
 def convertToByte(file_size):
 
     # if unit is not in Byte
@@ -125,20 +138,20 @@ def convertToByte(file_size):
         size_value = int(float(file_size[:-3]))
 
     # covert them in byte
-    if not(unit):
+    if not (unit):
         in_byte_value = size_value
 
     elif unit == 'KiB':
-        in_byte_value = size_value*1024
+        in_byte_value = size_value * 1024
 
     elif unit == 'MiB':
-        in_byte_value = size_value*1024*1024
+        in_byte_value = size_value * 1024 * 1024
 
     elif unit == 'GiB':
-        in_byte_value = size_value*1024*1024*1024
+        in_byte_value = size_value * 1024 * 1024 * 1024
 
     elif unit == 'TiB':
-        in_byte_value = size_value*1024*1024*1024*1024
+        in_byte_value = size_value * 1024 * 1024 * 1024 * 1024
 
     return int(in_byte_value)
 
@@ -172,8 +185,7 @@ def returnDefaultSettings():
     # user download folder path
     download_path = os.path.join(home_address, 'Downloads', 'Persepolis')
 
-
-    # set dark fusion for default style settings. 
+    # set dark fusion for default style settings.
     style = 'Fusion'
     color_scheme = 'Dark Fusion'
     icons = 'Breeze-Dark'
@@ -194,19 +206,21 @@ def returnDefaultSettings():
     default_setting_dict = {'locale': 'en_US', 'toolbar_icon_size': 32, 'wait-queue': [0, 0], 'awake': 'no', 'custom-font': 'no', 'column0': 'yes',
                             'column1': 'yes', 'column2': 'yes', 'column3': 'yes', 'column4': 'yes', 'column5': 'yes', 'column6': 'yes', 'column7': 'yes',
                             'column10': 'yes', 'column11': 'yes', 'column12': 'yes', 'subfolder': 'yes', 'startup': 'no', 'show-progress': 'yes',
-                            'show-menubar': 'no', 'show-sidepanel': 'yes', 'rpc-port': 6801, 'notification': 'Native notification', 'after-dialog': 'yes',
-                            'tray-icon': 'yes', 'browser-persepolis': 'yes', 'hide-window': 'yes', 'max-tries': 5, 'retry-wait': 0, 'timeout': 60,
-                            'connections': 16, 'download_path': download_path, 'sound': 'yes', 'sound-volume': 100,
-                            'style': style, 'color-scheme': color_scheme, 'icons': icons, 'font': 'Ubuntu', 'font-size': 9, 'aria2_path': '',
+                            'show-menubar': 'no', 'show-sidepanel': 'yes', 'notification': 'Native notification', 'after-dialog': 'yes',
+                            'tray-icon': 'yes', 'browser-persepolis': 'yes', 'hide-window': 'yes', 'max-tries': 5, 'retry-wait': 1, 'timeout': 5,
+                            'connections': 64, 'download_path': download_path, 'sound': 'yes', 'sound-volume': 100, 'chunk-size': 100,
+                            'style': style, 'color-scheme': color_scheme, 'icons': icons, 'font': 'Ubuntu', 'font-size': 9,
                             'video_finder/max_links': '3', 'shortcuts/delete_shortcut': delete_shortcut, 'shortcuts/remove_shortcut': remove_shortcut,
                             'shortcuts/add_new_download_shortcut': add_new_download_shortcut, 'shortcuts/import_text_shortcut': import_text_shortcut,
                             'shortcuts/video_finder_shortcut': video_finder_shortcut, 'shortcuts/quit_shortcut': quit_shortcut,
                             'shortcuts/hide_window_shortcut': hide_window_shortcut, 'shortcuts/move_up_selection_shortcut': move_up_selection_shortcut,
-                            'shortcuts/move_down_selection_shortcut': move_down_selection_shortcut, 'dont-check-certificate': 'no', 'remote-time': 'no'}
+                            'shortcuts/move_down_selection_shortcut': move_down_selection_shortcut, 'dont-check-certificate': 'no'}
 
     return default_setting_dict
 
 # mix video and audio that downloads by video finder
+
+
 def muxer(parent, video_finder_dictionary):
 
     result_dictionary = {'error': 'no_error',
@@ -280,14 +294,14 @@ def muxer(parent, video_finder_dictionary):
 
             # run ffmpeg
             command_argument = ['ffmpeg', '-i', video_file_path,
-                                         '-i', audio_file_path,
-                                         '-c', 'copy',
-                                         '-shortest',
-                                         '-map', '0:v:0',
-                                         '-map', '1:a:0',
-                                         '-loglevel', 'error',
-                                         '-strict', '-2',
-                                         final_path_plus_name]
+                                '-i', audio_file_path,
+                                '-c', 'copy',
+                                '-shortest',
+                                '-map', '0:v:0',
+                                '-map', '1:a:0',
+                                '-loglevel', 'error',
+                                '-strict', '-2',
+                                final_path_plus_name]
 
             pipe = runApplication(command_argument)
 
@@ -306,81 +320,6 @@ def muxer(parent, video_finder_dictionary):
 
     return result_dictionary
 
-# return version of gost
-def socks5ToHttpConvertorVersion():
-    type_of_convertor = None
-    # persepolis use gost, pproxy, sthp for converting socks5 to http
-    # try to find sthp
-    sthp_command, log_list = findExternalAppPath('sthp')
-    command_argument = [sthp_command, '--version']
-    try:
-        pipe = runApplication(command_argument)
-
-        if pipe.wait() == 0:
-            socks5_to_http_convertor_is_installed = True
-            type_of_convertor = 'sthp'
-            sthp_output, error = pipe.communicate()
-            sthp_output = sthp_output.decode('utf-8')
-
-        else:
-            socks5_to_http_convertor_is_installed = False
-    except:
-        socks5_to_http_convertor_is_installed = False
-
-    if socks5_to_http_convertor_is_installed:
-        return socks5_to_http_convertor_is_installed, sthp_output, log_list, type_of_convertor
-
-    else:
-
-        # find gost path
-        gost_command, log_list = findExternalAppPath('gost')
-
-        # Try to test gost
-        command_argument = [gost_command, '-V']
-        try:
-            pipe = runApplication(command_argument)
-
-            if pipe.wait() == 0:
-                socks5_to_http_convertor_is_installed = True
-                type_of_convertor = 'gost'
-                gost_output, error = pipe.communicate()
-                gost_output = gost_output.decode('utf-8')
-
-            else:
-                socks5_to_http_convertor_is_installed = False
-        except:
-            socks5_to_http_convertor_is_installed = False
-
-    if socks5_to_http_convertor_is_installed:
-        return socks5_to_http_convertor_is_installed, gost_output, log_list, type_of_convertor
-
-
-
-
-    else:
-
-        # try to find pproxy
-        pproxy_command, log_list = findExternalAppPath('pproxy')
-        command_argument = [pproxy_command, '--version']
-        try:
-            pipe = runApplication(command_argument)
-
-            if pipe.wait() == 0:
-                socks5_to_http_convertor_is_installed = True
-                type_of_convertor = 'pproxy'
-                pproxy_output, error = pipe.communicate()
-                pproxy_output = pproxy_output.decode('utf-8')
-
-            else:
-                socks5_to_http_convertor_is_installed = False
-                pproxy_output = 'No socks to http convertor found.'
-        except:
-            socks5_to_http_convertor_is_installed = False
-            pproxy_output = 'No socks to http convertor found.'
-
-
-
-    return socks5_to_http_convertor_is_installed, pproxy_output, log_list, type_of_convertor
 
 # return version of ffmpeg
 def ffmpegVersion():
@@ -388,8 +327,6 @@ def ffmpegVersion():
     # find ffmpeg path
     ffmpeg_command, log_list = findExternalAppPath('ffmpeg')
 
-    
-
     # Try to test ffmpeg
     command_argument = [ffmpeg_command, '-version']
     try:
@@ -426,6 +363,8 @@ def qRunApplication(command: str, command_argument: list, parent=None):
     return process
 
 # run an application
+
+
 def runApplication(command_argument):
     if os_type == OS.WINDOWS:
 
@@ -449,8 +388,10 @@ def runApplication(command_argument):
     return pipe
 
 # find exeternal application execution path
+
+
 def findExternalAppPath(app_name):
-    
+
     # get Persepolis type information first.
     persepolis_path_infromation = getExecPath()
     is_bundle = persepolis_path_infromation['bundle']
@@ -462,7 +403,7 @@ def findExternalAppPath(app_name):
     # If Persepolis run as a bundle.
     if is_bundle:
 
-        # alongside of the bundle path 
+        # alongside of the bundle path
         cwd = sys.argv[0]
         current_directory = os.path.dirname(cwd)
         app_alongside = os.path.join(current_directory, app_name)
@@ -479,14 +420,14 @@ def findExternalAppPath(app_name):
                 log_list = ["{}'s file is detected alongside of bundle.".format(app_name), "INFO"]
 
             # Check inside of the bundle.
-            elif os.path.exists(app_inside): 
+            elif os.path.exists(app_inside):
 
                 app_command = app_inside
                 log_list = ["{}'s file is detected inside of bundle.".format(app_name), "INFO"]
 
             else:
                 # use app that installed on user's system
-                app_command = app_name 
+                app_command = app_name
                 log_list = ["Persepolis will use {} that installed on user's system.".format(app_name), "INFO"]
 
         else:
@@ -498,7 +439,7 @@ def findExternalAppPath(app_name):
     # I Persepolis run from test directory.
     if is_test:
 
-        # Check inside of test directory. 
+        # Check inside of test directory.
         cwd = sys.argv[0]
         current_directory = os.path.dirname(cwd)
         app_alongside = os.path.join(current_directory, app_name)
@@ -510,13 +451,12 @@ def findExternalAppPath(app_name):
 
         else:
             # use app that installed on user's system
-            app_command = app_name 
+            app_command = app_name
             log_list = ["Persepolis will use {} that installed on user's system.".format(app_name), "INFO"]
 
+    if not (is_bundle) and not (is_test):
 
-    if not(is_bundle) and not(is_test):
-
-        app_command = app_name 
+        app_command = app_name
         log_list = ["Persepolis will use {} that installed on user's system.".format(app_name), "INFO"]
 
     return app_command, log_list
@@ -536,21 +476,19 @@ def getExecPath():
 
         # get executable path
         bundle_path = os.path.dirname(sys.executable)
-        
+
         # get bundle name
         bundle_name = os.path.basename(sys.executable)
 
-
         exec_file_path = os.path.join(bundle_path, bundle_name)
 
-           
     else:
         # persepolis is run from python script
         exec_dictionary['bundle'] = False
 
         # get execution path
         script_path = os.path.dirname(os.path.abspath(sys.modules['__main__'].__file__))
-        script_name = os.path.basename(sys.argv[0]) 
+        script_name = os.path.basename(sys.argv[0])
 
         if script_name == 'test.py':
 
@@ -559,7 +497,6 @@ def getExecPath():
 
         exec_file_path = os.path.join(script_path, script_name)
 
-
     # replace space with \+space for UNIX_LIKE and OSX
     if os_type in OS.UNIX_LIKE or os_type == OS.OSX:
 
@@ -569,8 +506,15 @@ def getExecPath():
         modified_exec_file_path = exec_file_path.replace('\\', r'\\')
 
     # write it in dictionary
-    exec_dictionary['exec_file_path'] = exec_file_path 
+    exec_dictionary['exec_file_path'] = exec_file_path
     exec_dictionary['modified_exec_file_path'] = modified_exec_file_path
 
     # return ressults
     return exec_dictionary
+
+
+# This method returns data and time in string format
+# for example >> 2017/09/09 , 13:12:26
+def nowDate():
+    date = time.strftime("%Y/%m/%d , %H:%M:%S")
+    return date
